diff --git a/src/backend/port/sysv_shmem.c b/src/backend/port/sysv_shmem.c
index 9de96ed..61b2fd2 100644
--- a/src/backend/port/sysv_shmem.c
+++ b/src/backend/port/sysv_shmem.c
@@ -592,8 +592,11 @@ CreateAnonymousSegment(Size *size)
 				   PG_MMAP_FLAGS | mmap_flags, -1, 0);
 		mmap_errno = errno;
 		if (huge_pages == HUGE_PAGES_TRY && ptr == MAP_FAILED)
-			elog(DEBUG1, "mmap(%zu) with MAP_HUGETLB failed, huge pages disabled: %m",
-				 allocsize);
+			ereport(LOG,
+					(errmsg("could not map anonymous shared memory (%zu bytes)"
+						" with huge pages enabled.", allocsize),
+				 	 errdetail("The server will map anonymous shared memory "
+						"again with huge pages disabled." )));
 	}
 #endif
 
diff --git a/src/backend/port/win32_shmem.c b/src/backend/port/win32_shmem.c
index d7a7199..986d43f 100644
--- a/src/backend/port/win32_shmem.c
+++ b/src/backend/port/win32_shmem.c
@@ -293,9 +293,11 @@ retry:
 				huge_pages == HUGE_PAGES_TRY &&
 				(flProtect & SEC_LARGE_PAGES) != 0)
 			{
-				elog(DEBUG1, "CreateFileMapping(%zu) with SEC_LARGE_PAGES failed, "
-					 "huge pages disabled",
-					 size);
+				ereport(LOG,
+						(errmsg("could not create anonymous shared memory (%zu bytes)"
+							" with huge pages enabled.", size),
+						 errdetail("The server will map anonymous shared memory "
+							"again with huge pages disabled.")));
 
 				/*
 				 * Use the original size, not the rounded-up value, when
